@@ -71,36 +71,34 @@ class Markup:
 
     # Helpers
 
-    def add_style(self, source, *, action="append", target="head", **context):
-        plugin = self.get_plugin()
+    def add_style(self, source, *, target="head", action="append", **context):
         style = f'<link rel="stylesheet" href="{source}"></script>\n'
         if not helpers.is_remote_path(source):
-            style = plugin.read_asset(source, **context)
+            if not self.__plugin:
+                raise LivemarkException("Markup is not bound")
+            style = self.__plugin.read_asset(source, **context)
             style = f"<style>\n\n{style}\n\n</style>\n"
         if style in self.__styles:
             return
         self.__styles.add(style)
         getattr(self.__query(target), action)(style)
 
-    def add_script(self, source, *, action="append", target="body", **context):
-        plugin = self.get_plugin()
+    def add_script(self, source, *, target="body", action="append", **context):
         script = f'<script src="{source}"></script>\n'
         if not helpers.is_remote_path(source):
-            script = plugin.read_asset(source, **context)
+            if not self.__plugin:
+                raise LivemarkException("Markup is not bound")
+            script = self.__plugin.read_asset(source, **context)
             script = f"<script>\n\n{script}\n\n</script>\n"
         if script in self.__scripts:
             return
         self.__scripts.add(script)
         getattr(self.__query(target), action)(script)
 
-    def add_markup(self, source, *, action="append", target="body", **context):
+    def add_markup(self, source, *, target="body", action="append", **context):
         markup = source
-        plugin = self.get_plugin()
         if not source.strip().startswith("<"):
-            markup = plugin.read_asset(source, **context)
+            if not self.__plugin:
+                raise LivemarkException("Markup is not bound")
+            markup = self.__plugin.read_asset(source, **context)
         getattr(self.__query(target), action)(f"\n{markup}\n")
-
-    def get_plugin(self):
-        if not self.__plugin:
-            raise LivemarkException("Markup is not bound to any plugin")
-        return self.__plugin
