@@ -1,7 +1,6 @@
 import os
 import inspect
 from jinja2 import Template
-from .exception import LivemarkException
 from .helpers import cached_property
 
 
@@ -17,34 +16,24 @@ class Plugin:
 
     """
 
-    property = cached_property
+    name = ""
     priority = 0
     profile = {}
+    property = cached_property
 
     def __init__(self, document):
         self.__document = document
-        self.process_plugin()
 
     @property
-    def name(self):
-        return self.__class__.__name__.replace("Plugin", "").lower()
+    def config(self):
+        return self.__document.config.get(self.name, {})
 
     @property
     def document(self):
         return self.__document
 
-    @property
-    def config(self):
-        return self.__document.config[self.name]
-
     # Actions
 
-    def process_plugin(self):
-        pass
-
-    def process_config(self, config):
-        pass
-
     def process_document(self, document):
         pass
 
@@ -56,18 +45,17 @@ class Plugin:
 
     # Helpers
 
-    def get_plugin(self, name):
-        for plugin in self.document.plugins:
-            if plugin.name == name:
-                return plugin
-        raise LivemarkException(f"Plugin is not registered: {name}")
+    @classmethod
+    def get_type(cls):
+        if cls.__module__.startswith("livemark_"):
+            return "external"
+        return "internal"
 
     def read_asset(self, *path, **context):
         dir = os.path.dirname(inspect.getfile(self.__class__))
         path = os.path.join(dir, *path)
+        context["plugin"] = self
         with open(path) as file:
-            text = file.read().strip()
-        if context:
-            template = Template(text, trim_blocks=True)
+            template = Template(file.read().strip(), trim_blocks=True)
             text = template.render(**context)
         return text
