@@ -2,7 +2,8 @@ from ...plugin import Plugin
 
 
 class AboutPlugin(Plugin):
-    priority = 30
+    name = "about"
+    priority = 20
     profile = {
         "type": "object",
         "properties": {
@@ -19,11 +20,5 @@ class AboutPlugin(Plugin):
     # Process
 
     def process_markup(self, markup):
-        if self.config:
-            markup.add_style("style.css")
-            markup.add_markup(
-                "markup.html",
-                target="#livemark-right",
-                # TODO: pass self as "plugin" automatically (in all plugins)?
-                text=self.text,
-            )
+        markup.add_style("style.css")
+        markup.add_markup("markup.html", target="#livemark-right")
