@@ -4,7 +4,8 @@ from ...plugin import Plugin
 
 
 class NotesPlugin(Plugin):
-    priority = 60
+    name = "notes"
+    priority = 50
     profile = {
         "type": "object",
         "properties": {
@@ -25,12 +26,5 @@ class NotesPlugin(Plugin):
     # Process
 
     def process_markup(self, markup):
-        if self.config:
-            markup.add_style("style.css")
-            markup.add_markup(
-                "markup.html",
-                action="prepend",
-                target="#livemark-main",
-                format=self.format,
-                current=self.current,
-            )
+        markup.add_style("style.css")
+        markup.add_markup("markup.html", target="#livemark-main", action="prepend")
