@@ -3,7 +3,8 @@ from ...plugin import Plugin
 
 
 class PreparePlugin(Plugin):
-    priority = 110
+    name = "prepare"
+    priority = 100
     profile = {
         "type": "object",
         "required": ["commands"],
@@ -12,12 +13,14 @@ class PreparePlugin(Plugin):
         },
     }
 
+    # Context
+
+    @Plugin.property
+    def commands(self):
+        return self.config.get("commands", [])
+
     # Process
 
-    def process_config(self, config):
-        self.config.setdefault("commands", self.config.pop("self", []))
-
     def process_document(self, document):
-        if self.config:
-            for code in self.config["commands"]:
-                subprocess.run(code, shell=True)
+        for code in self.commands:
+            subprocess.run(code, shell=True)
