@@ -2,7 +2,8 @@ from ...plugin import Plugin
 
 
 class RatingPlugin(Plugin):
-    priority = 40
+    name = "rating"
+    priority = 30
     profile = {
         "type": "object",
         "properties": {
@@ -18,23 +19,19 @@ class RatingPlugin(Plugin):
 
     @Plugin.property
     def user(self):
-        github = self.get_plugin("github")
-        return github.user
+        github = self.document.get_plugin("github")
+        if github:
+            return github.user
 
     @Plugin.property
     def repo(self):
-        github = self.get_plugin("github")
-        return github.repo
+        github = self.document.get_plugin("github")
+        if github:
+            return github.repo
 
     # Process
 
     def process_markup(self, markup):
-        if self.config and self.user and self.repo:
+        if self.user and self.repo:
             markup.add_style("style.css")
-            markup.add_markup(
-                "markup.html",
-                target="#livemark-right",
-                user=self.user,
-                repo=self.repo,
-                type=self.type,
-            )
+            markup.add_markup("markup.html", target="#livemark-right")
