@@ -4,15 +4,17 @@ from ...plugin import Plugin
 from ... import helpers
 
 
-# TODO: support snippet.props['mode'] = 'input' | 'output'
 class ScriptPlugin(Plugin):
+    name = "script"
+    priority = 100
 
     # Process
 
-    def process_plugin(self):
+    def __init__(self, document):
+        super().__init__(document)
         self.__store = []
 
-    def process_config(self, config):
+    def process_document(self, config):
         self.__index = 0
 
     def process_snippet(self, snippet):
