@@ -1,15 +1,16 @@
 import json
 import yaml
-from jinja2 import Template
 from frictionless import Resource, Detector
 from ...plugin import Plugin
 
 
 class TablePlugin(Plugin):
+    name = "table"
+    priority = 100
 
     # Process
 
-    def process_config(self, config):
+    def process_document(self, document):
         self.__count = 0
 
     def process_snippet(self, snippet):
@@ -26,10 +27,9 @@ class TablePlugin(Plugin):
                     spec_python["data"] = lists
                     spec = json.dumps(spec_python, ensure_ascii=False)
                     spec = spec.replace("'", "\\'")
-                    template = Template(self.read_asset("markup.html"))
                     self.__count += 1
                     table = {"spec": spec, "elem": f"livemark-table-{self.__count}"}
-                    snippet.output = template.render(table=table) + "\n"
+                    snippet.output = self.read_asset("markup.html", table=table) + "\n"
 
     def process_markup(self, markup):
         markup.add_style("https://unpkg.com/handsontable@9.0.0/dist/handsontable.min.css")
