@@ -4,7 +4,8 @@ from ...plugin import Plugin
 # TODO: limit selector levels?
 # TODO: support two-level menu items?
 class TopicsPlugin(Plugin):
-    priority = 70
+    name = "topics"
+    priority = 60
     profile = {
         "type": "object",
         "properties": {
@@ -21,11 +22,7 @@ class TopicsPlugin(Plugin):
     # Process
 
     def process_markup(self, markup):
-        if self.config:
-            markup.add_style("style.css")
-            markup.add_script("https://unpkg.com/tocbot@4.12.3/dist/tocbot.min.js")
-            markup.add_script("script.js", selector=self.selector)
-            markup.add_markup(
-                "markup.html",
-                target="#livemark-left",
-            )
+        markup.add_style("style.css")
+        markup.add_script("https://unpkg.com/tocbot@4.12.3/dist/tocbot.min.js")
+        markup.add_script("script.js")
+        markup.add_markup("markup.html", target="#livemark-left")
