@@ -1,7 +1,10 @@
+import os
 import sys
 import typer
 from ..server import Server
+from ..project import Project
 from ..document import Document
+from ..exception import LivemarkException
 from .main import program
 from . import common
 
@@ -22,26 +25,27 @@ def program_build(
 
     try:
 
-        # TODO:
-        # Build with no source should build all the documents?
+        # Validate project
+        if not os.path.exists(config):
+            if not source:
+                message = 'Project without config requires "source" argument'
+                raise LivemarkException(message)
 
-        # Create document
-        document = Document(
-            source,
-            target=target,
-            format=format,
-            config=config,
-        )
+        # Create project
+        document = None
+        if source:
+            document = Document(source, target=target, format=format)
+        project = Project(document, config=config, format=format)
 
         # Normal mode
         if not live:
-            output = document.build(diff=diff, print=print)
+            output = project.build(diff=diff, print=print)
             if output and diff:
                 sys.exit(1)
             sys.exit(0)
 
         # Live mode
-        server = Server(document)
+        server = Server(project)
         server.start(host=host, port=port)
 
     except Exception as exception:
