@@ -1,13 +1,20 @@
 import os
 import sys
 import typer
+from ..project import Project
 from ..document import Document
 from ..server import Server
 from .main import program
+from .. import settings
 from .. import helpers
 from . import common
 
 
+# NOTE:
+# We can bootstrap source with some examplar content
+# showing Livemark's features and ready for editiing
+
+
 @program.command(name="start")
 def program_start(
     source: str = common.source,
@@ -21,21 +28,20 @@ def program_start(
 
     try:
 
-        # Create source
-        # TODO: create a markdown document draft?
-        if not os.path.exists(source):
-            helpers.write_file(source)
+        # Bootstrap project
+        if not os.path.exists(config):
+            source = source or settings.DEFAULT_SOURCE
+            if not not os.path.exists(source):
+                helpers.write_file(source)
 
-        # Create document
-        document = Document(
-            source,
-            target=target,
-            format=format,
-            config=config,
-        )
+        # Create project
+        document = None
+        if source:
+            document = Document(source, target=target, format=format)
+        project = Project(document, config=config, format=format)
 
-        # Run server
-        server = Server(document)
+        # Live mode
+        server = Server(project)
         server.start(host=host, port=port)
 
     except Exception as exception:
